@@ -16,17 +16,25 @@
 * limitations under the License.
 */
 
+#include "BitArray.h"
+
+#include <string>
+
 namespace ZXing {
 
 class Result;
-class BitArray;
 
 namespace OneD {
 
+namespace UPCEANExtension5Support {
+int ExtensionChecksum(const std::string& s);
+std::string ParseExtension5String(const std::string& raw);
+} // namespace UPCEANExtension5Support
+
 class UPCEANExtensionSupport
 {
 public:
-	static Result DecodeRow(int rowNumber, const BitArray& row, int rowOffset);
+	static Result DecodeRow(int rowNumber, const BitArray& row, BitArray::Iterator begin);
 };
 
 
